'use strict';

import ReduxBinder from './binder';
import {provide, Injector} from '@angular/core';
import redux from 'redux';

/**
 * Provides the component with a bound redux store.
 *
 *
 * Use like:
 *
 * import { reduxBindProvider } from './provider';
 * const store = configureStore();
 *
 * bootstrap(
 *      App,
 *      [
 *          reduxBindProvider(store),
 *          devTools
 *      ]
 * );
 *
 * @param store
 * @returns {*|any|Provider}
 *
 */

export function reduxBindProvider(store = {}) {

    const reduxBinder = ReduxBinder(store);

    // this is a bit of an experiment for now.
    // will test around which angular bind methods make sense and
    // how they work, but I have a feel that factory will be the right one.
    return provide('reduxStore', {
        useFactory: () => {
            console.log('BINDER', reduxBinder);
            return Object.assign({}, reduxBinder, store);
        }
    });
}

export default reduxBindProvider;
