'use strict';

import 'zone.js/lib/browser/zone-microtask';
import 'reflect-metadata';
import 'babel-polyfill';

import {reduxBindProvider} from '../reduxBind/provider';
import store from './store';
import {TEST_ACTION} from './store';

import {
    Component, View, Attribute, provide
} from 'angular2/core';

import { InjectMetadata } from 'angular2/core';
import {bootstrap} from 'angular2/bootstrap';


@Component({
    selector: 'content',
    appInjector: [reduxBindProvider(store)]
})
@View({
    templateUrl: './content.html'
})
@Reflect.metadata('parameters', [[new InjectMetadata('reduxStore')]])
class Content {

    constructor(reduxStore) {

        this.reduxStore = reduxStore;
        this.appState = {test: ''};

        // Create observable sequence for store updates.
        let src = this.reduxStore.createObservable();
        this.unsubscribe = this.reduxStore.bindStore()(this);

        src.subscribe(
            appState => {
                console.log('RECEIVED OBSERVABLE UPDATE FROM REDUX', appState);
            },
            err => {
                console.log(err);
            }
        );

        setTimeout(() => {
            let t = {
                type: TEST_ACTION,
                msg: 'success if you see this'
            };
            console.log('DISPATCHING EVENT', t);
            this.reduxStore.dispatch(t, 500);
        });

        setTimeout(() => {
            console.log('Component\'s appState property updated through binding:', this.appState)
        }, 500);

    }
}

bootstrap(Content, [
    reduxBindProvider(store)
]);
